@@ -47,6 +47,9 @@ class AppInfoItem(AbstractModel):
         :param BehaviorTitle: 小程序隐私诊断堆栈报告名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type BehaviorTitle: str
+        :param HighRiskCount: 诊断风险项数量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type HighRiskCount: int
         """
         self.AppPackage = None
         self.AppName = None
@@ -56,6 +59,7 @@ class AppInfoItem(AbstractModel):
         self.ReportTitle = None
         self.BehaviorUrl = None
         self.BehaviorTitle = None
+        self.HighRiskCount = None
 
 
     def _deserialize(self, params):
@@ -67,6 +71,7 @@ class AppInfoItem(AbstractModel):
         self.ReportTitle = params.get("ReportTitle")
         self.BehaviorUrl = params.get("BehaviorUrl")
         self.BehaviorTitle = params.get("BehaviorTitle")
+        self.HighRiskCount = params.get("HighRiskCount")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -439,6 +444,63 @@ class CreateFlySecMiniAppScanTaskResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeBasicDiagnosisResourceUsageInfoRequest(AbstractModel):
+    """DescribeBasicDiagnosisResourceUsageInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Mode: 诊断模式 1:基础诊断，2:深度诊断
+        :type Mode: int
+        """
+        self.Mode = None
+
+
+    def _deserialize(self, params):
+        self.Mode = params.get("Mode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeBasicDiagnosisResourceUsageInfoResponse(AbstractModel):
+    """DescribeBasicDiagnosisResourceUsageInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Ret: 返回值, 0:成功, 其他值请查看“返回值”定义
+        :type Ret: int
+        :param ResourceName: 资源类型
+        :type ResourceName: str
+        :param Total: 资源总数
+        :type Total: int
+        :param UnusedCount: 资源未使用次数
+        :type UnusedCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Ret = None
+        self.ResourceName = None
+        self.Total = None
+        self.UnusedCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Ret = params.get("Ret")
+        self.ResourceName = params.get("ResourceName")
+        self.Total = params.get("Total")
+        self.UnusedCount = params.get("UnusedCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeFlySecMiniAppReportUrlRequest(AbstractModel):
     """DescribeFlySecMiniAppReportUrl请求参数结构体
 
@@ -705,6 +767,46 @@ class DescribeFlySecMiniAppScanTaskStatusResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeResourceUsageInfoRequest(AbstractModel):
+    """DescribeResourceUsageInfo请求参数结构体
+
+    """
+
+
+class DescribeResourceUsageInfoResponse(AbstractModel):
+    """DescribeResourceUsageInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Ret: 返回值, 0:成功, 其他值请查看“返回值”定义
+        :type Ret: int
+        :param Data: 安全资源数据列表
+        :type Data: list of ResourceUsageInfoData
+        :param Total: 安全资源数量
+        :type Total: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Ret = None
+        self.Data = None
+        self.Total = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Ret = params.get("Ret")
+        if params.get("Data") is not None:
+            self.Data = []
+            for item in params.get("Data"):
+                obj = ResourceUsageInfoData()
+                obj._deserialize(item)
+                self.Data.append(obj)
+        self.Total = params.get("Total")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeScanTaskListRequest(AbstractModel):
     """DescribeScanTaskList请求参数结构体
 
@@ -716,9 +818,9 @@ class DescribeScanTaskListRequest(AbstractModel):
         :type Source: int
         :param Platform: 应用平台, 0:android, 1:ios, 2:小程序
         :type Platform: int
-        :param TaskStatuses: 任务状态,可多值查询,比如:"1,2,3" 0:默认值(待检测/待咨询), 1.检测中, 2:待评估, 3:评估中, 4:任务完成/咨询完成, 5:任务失败, 6:咨询中;
+        :param TaskStatuses: 任务状态,可多值查询,例如:"1,2,3" 0:默认值(待检测/待咨询), 1.检测中, 2:待评估, 3:评估中, 4:任务完成/咨询完成, 5:任务失败, 6:咨询中;
         :type TaskStatuses: str
-        :param TaskTypes: 任务类型,可多值查询,采用逗号分隔,比如:"0,1" 0:基础版, 1:专家版, 2:本地化
+        :param TaskTypes: 任务类型,可多值查询,采用逗号分隔,例如:"0,1" 0:基础版, 1:专家版, 2:本地化
         :type TaskTypes: str
         :param PageNo: 页码
         :type PageNo: int
@@ -995,6 +1097,38 @@ class FlySecMiniAppTaskData(AbstractModel):
         
 
 
+class ResourceUsageInfoData(AbstractModel):
+    """翼扬安全资源使用情况
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ResourceName: 资源名称, 具体名称请查看产品配置
+        :type ResourceName: str
+        :param Total: 资源总数
+        :type Total: int
+        :param UnusedCount: 资源未使用次数
+        :type UnusedCount: int
+        """
+        self.ResourceName = None
+        self.Total = None
+        self.UnusedCount = None
+
+
+    def _deserialize(self, params):
+        self.ResourceName = params.get("ResourceName")
+        self.Total = params.get("Total")
+        self.UnusedCount = params.get("UnusedCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class TaskFlowStepsInfo(AbstractModel):
     """任务流步骤详情
 
