@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,9 +32,18 @@ FAILEDOPERATION_ACCESSSTSFAIL = 'FailedOperation.AccessSTSFail'
 # 访问用户TKE集群失败。
 FAILEDOPERATION_ACCESSTKEFAIL = 'FailedOperation.AccessTKEFail'
 
+# 访问标签服务失败。
+FAILEDOPERATION_ACCESSTAGFAIL = 'FailedOperation.AccessTagFail'
+
+# agent当前状态不允许该操作。
+FAILEDOPERATION_AGENTNOTALLOWED = 'FailedOperation.AgentNotAllowed'
+
 # Agent版本不支持该操作，请升级Agent。
 FAILEDOPERATION_AGENTVERSIONNOTSUPPORTED = 'FailedOperation.AgentVersionNotSupported'
 
+# 该实例上有正在运行的Agent。
+FAILEDOPERATION_AGENTSNOTINUNINSTALLSTAGE = 'FailedOperation.AgentsNotInUninstallStage'
+
 # 删除过滤条件失败。
 FAILEDOPERATION_ALERTFILTERRULEDELETEFAILED = 'FailedOperation.AlertFilterRuleDeleteFailed'
 
@@ -101,6 +110,9 @@ FAILEDOPERATION_DUPLICATENAME = 'FailedOperation.DuplicateName'
 # 生成资源ID错误。
 FAILEDOPERATION_GENERATEINSTANCEIDFAILED = 'FailedOperation.GenerateInstanceIDFailed'
 
+# 实例不存在。
+FAILEDOPERATION_INSTANCENOTFOUND = 'FailedOperation.InstanceNotFound'
+
 # 实例没有运行。
 FAILEDOPERATION_INSTANCENOTRUNNING = 'FailedOperation.InstanceNotRunning'
 
@@ -110,6 +122,12 @@ FAILEDOPERATION_RESOURCEEXIST = 'FailedOperation.ResourceExist'
 # 资源不存在。
 FAILEDOPERATION_RESOURCENOTFOUND = 'FailedOperation.ResourceNotFound'
 
+# 资源正在被操作。
+FAILEDOPERATION_RESOURCEOPERATING = 'FailedOperation.ResourceOperating'
+
+# 发送授权请求失败。
+FAILEDOPERATION_SENDREQUEST = 'FailedOperation.SendRequest'
+
 # 服务未启用，开通服务后方可使用。
 FAILEDOPERATION_SERVICENOTENABLED = 'FailedOperation.ServiceNotEnabled'
 
