@@ -32,6 +32,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 参数冲突。
 INVALIDPARAMETER_CONFLICTPARAMETER = 'InvalidParameter.ConflictParameter'
 
+# 无效用户名。
+INVALIDPARAMETER_INVALIDUSERNAME = 'InvalidParameter.InvalidUsername'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -83,6 +86,9 @@ INVALIDPARAMETERVALUE_INVALIDOUTPUTCOSBUCKETURL = 'InvalidParameterValue.Invalid
 # OutputCOSKeyPrefix 无效。
 INVALIDPARAMETERVALUE_INVALIDOUTPUTCOSKEYPREFIX = 'InvalidParameterValue.InvalidOutputCOSKeyPrefix'
 
+# 用户名不合法。
+INVALIDPARAMETERVALUE_INVALIDUSERNAME = 'InvalidParameterValue.InvalidUsername'
+
 # 命令执行路径不合法。
 INVALIDPARAMETERVALUE_INVALIDWORKINGDIRECTORY = 'InvalidParameterValue.InvalidWorkingDirectory'
 
@@ -128,6 +134,9 @@ INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 填写的 Filter 取值过多。
+LIMITEXCEEDED_FILTERVALUEEXCEEDED = 'LimitExceeded.FilterValueExceeded'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -158,6 +167,9 @@ RESOURCEUNAVAILABLE_COMMANDININVOKER = 'ResourceUnavailable.CommandInInvoker'
 # 实例未处于运行中。
 RESOURCEUNAVAILABLE_INSTANCESTATENOTRUNNING = 'ResourceUnavailable.InstanceStateNotRunning'
 
+# Lighthouse 尚不支持指定的地域。
+RESOURCEUNAVAILABLE_LIGHTHOUSEUNSUPPORTEDREGION = 'ResourceUnavailable.LighthouseUnsupportedRegion'
+
 # CAM鉴权失败。
 UNAUTHORIZEDOPERATION_CAMAUTHFAILED = 'UnauthorizedOperation.CamAuthFailed'
 
